@@ -3,10 +3,12 @@ from SlyYTAAPI import *
 
 async def test_readme():
 
-    analytics = await YouTubeAnalytics('UCxATMl-Cv8BEF0FtZMRvRgA', 'test/app.json', 'test/user.json')
+    auth = OAuth2('test/app.json', 'test/user.json')
+    analytics = YouTubeAnalytics('UCxATMl-Cv8BEF0FtZMRvRgA', auth)
 
     result = await analytics.query(
         since=date(2020, 1, 1),
+        end_date=date(2021, 1, 1),
         metrics=Metrics.SubsGained+Metrics.SubsLost+Metrics.WatchTime,
         dims=Dimensions.Day
         )
